@@ -5,6 +5,7 @@ from enum import Enum
 
 from sqlglot import exp
 from sqlglot._typing import E
+from sqlglot.errors import ParseError
 from sqlglot.generator import Generator
 from sqlglot.helper import flatten, seq_get
 from sqlglot.parser import Parser
@@ -168,6 +169,10 @@ class Dialect(metaclass=_Dialect):
     # special syntax cast(x as date format 'yyyy') defaults to time_mapping
     FORMAT_MAPPING: t.Dict[str, str] = {}
 
+    # Columns that are auto-generated by the engine corresponding to this dialect
+    # Such columns may be excluded from SELECT * queries, for example
+    PSEUDOCOLUMNS: t.Set[str] = set()
+
     # Autofilled
     tokenizer_class = Tokenizer
     parser_class = Parser
@@ -341,7 +346,9 @@ def inline_array_sql(self: Generator, expression: exp.Array) -> str:
 
 def no_ilike_sql(self: Generator, expression: exp.ILike) -> str:
     return self.like_sql(
-        exp.Like(this=exp.Lower(this=expression.this), expression=expression.expression)
+        exp.Like(
+            this=exp.Lower(this=expression.this.copy()), expression=expression.expression.copy()
+        )
     )
 
 
@@ -405,7 +412,7 @@ def str_position_sql(self: Generator, expression: exp.StrPosition) -> str:
 
 def struct_extract_sql(self: Generator, expression: exp.StructExtract) -> str:
     this = self.sql(expression, "this")
-    struct_key = self.sql(exp.Identifier(this=expression.expression, quoted=True))
+    struct_key = self.sql(exp.Identifier(this=expression.expression.copy(), quoted=True))
     return f"{this}.{struct_key}"
 
 
@@ -497,6 +504,10 @@ def parse_date_delta_with_interval(
             return None
 
         interval = args[1]
+
+        if not isinstance(interval, exp.Interval):
+            raise ParseError(f"INTERVAL expression expected but got '{interval}'")
+
         expression = interval.this
         if expression and expression.is_string:
             expression = exp.Literal.number(expression.this)
@@ -555,11 +566,22 @@ def right_to_substring_sql(self: Generator, expression: exp.Left) -> str:
 
 
 def timestrtotime_sql(self: Generator, expression: exp.TimeStrToTime) -> str:
-    return f"CAST({self.sql(expression, 'this')} AS TIMESTAMP)"
+    return self.sql(exp.cast(expression.this, "timestamp"))
 
 
 def datestrtodate_sql(self: Generator, expression: exp.DateStrToDate) -> str:
-    return f"CAST({self.sql(expression, 'this')} AS DATE)"
+    return self.sql(exp.cast(expression.this, "date"))
+
+
+# Used for Presto and Duckdb which use functions that don't support charset, and assume utf-8
+def encode_decode_sql(
+    self: Generator, expression: exp.Expression, name: str, replace: bool = True
+) -> str:
+    charset = expression.args.get("charset")
+    if charset and charset.name.lower() != "utf-8":
+        self.unsupported(f"Expected utf-8 character set, got {charset}.")
+
+    return self.func(name, expression.this, expression.args.get("replace") if replace else None)
 
 
 def min_or_least(self: Generator, expression: exp.Min) -> str:
@@ -579,7 +601,7 @@ def count_if_to_sum(self: Generator, expression: exp.CountIf) -> str:
         cond = expression.this.expressions[0]
         self.unsupported("DISTINCT is not supported when converting COUNT_IF to SUM")
 
-    return self.func("sum", exp.func("if", cond, 1, 0))
+    return self.func("sum", exp.func("if", cond.copy(), 1, 0))
 
 
 def trim_sql(self: Generator, expression: exp.Trim) -> str:
@@ -608,13 +630,15 @@ def ts_or_ds_to_date_sql(dialect: str) -> t.Callable:
         _dialect = Dialect.get_or_raise(dialect)
         time_format = self.format_time(expression)
         if time_format and time_format not in (_dialect.TIME_FORMAT, _dialect.DATE_FORMAT):
-            return f"CAST({str_to_time_sql(self, expression)} AS DATE)"
-        return f"CAST({self.sql(expression, 'this')} AS DATE)"
+            return self.sql(exp.cast(str_to_time_sql(self, expression), "date"))
+
+        return self.sql(exp.cast(self.sql(expression, "this"), "date"))
 
     return _ts_or_ds_to_date_sql
 
 
 def concat_to_dpipe_sql(self: Generator, expression: exp.Concat | exp.SafeConcat) -> str:
+    expression = expression.copy()
     this, *rest_args = expression.expressions
     for arg in rest_args:
         this = exp.DPipe(this=this, expression=arg)
@@ -664,5 +688,14 @@ def pivot_column_names(aggregations: t.List[exp.Expression], dialect: DialectTyp
     return names
 
 
+def simplify_literal(expression: E) -> E:
+    if not isinstance(expression.expression, exp.Literal):
+        from sqlglot.optimizer.simplify import simplify
+
+        simplify(expression.expression)
+
+    return expression
+
+
 def binary_from_function(expr_type: t.Type[B]) -> t.Callable[[t.List], B]:
     return lambda args: expr_type(this=seq_get(args, 0), expression=seq_get(args, 1))
