@@ -109,6 +109,8 @@ class TestPresto(Validator):
                 "spark": "CAST(x AS TIMESTAMP)",
             },
         )
+        self.validate_identity("CAST(x AS IPADDRESS)")
+        self.validate_identity("CAST(x AS IPPREFIX)")
 
     def test_regex(self):
         self.validate_all(
@@ -459,6 +461,26 @@ class TestPresto(Validator):
         self.validate_identity("START TRANSACTION ISOLATION LEVEL REPEATABLE READ")
         self.validate_identity("APPROX_PERCENTILE(a, b, c, d)")
 
+        self.validate_all(
+            "STARTS_WITH('abc', 'a')",
+            read={"spark": "STARTSWITH('abc', 'a')"},
+            write={
+                "presto": "STARTS_WITH('abc', 'a')",
+                "snowflake": "STARTSWITH('abc', 'a')",
+                "spark": "STARTSWITH('abc', 'a')",
+            },
+        )
+        self.validate_all(
+            "IS_NAN(x)",
+            read={
+                "spark": "ISNAN(x)",
+            },
+            write={
+                "presto": "IS_NAN(x)",
+                "spark": "ISNAN(x)",
+                "spark2": "ISNAN(x)",
+            },
+        )
         self.validate_all("VALUES 1, 2, 3", write={"presto": "VALUES (1), (2), (3)"})
         self.validate_all("INTERVAL '1 day'", write={"trino": "INTERVAL '1' day"})
         self.validate_all("(5 * INTERVAL '7' day)", read={"": "INTERVAL '5' week"})
@@ -719,46 +741,44 @@ class TestPresto(Validator):
         )
 
     def test_encode_decode(self):
+        self.validate_identity("FROM_UTF8(x, y)")
+
         self.validate_all(
             "TO_UTF8(x)",
+            read={
+                "duckdb": "ENCODE(x)",
+                "spark": "ENCODE(x, 'utf-8')",
+            },
             write={
+                "duckdb": "ENCODE(x)",
+                "presto": "TO_UTF8(x)",
                 "spark": "ENCODE(x, 'utf-8')",
             },
         )
         self.validate_all(
             "FROM_UTF8(x)",
-            write={
+            read={
+                "duckdb": "DECODE(x)",
                 "spark": "DECODE(x, 'utf-8')",
             },
-        )
-        self.validate_all(
-            "FROM_UTF8(x, y)",
-            write={
-                "presto": "FROM_UTF8(x, y)",
-            },
-        )
-        self.validate_all(
-            "ENCODE(x, 'utf-8')",
-            write={
-                "presto": "TO_UTF8(x)",
-            },
-        )
-        self.validate_all(
-            "DECODE(x, 'utf-8')",
             write={
+                "duckdb": "DECODE(x)",
                 "presto": "FROM_UTF8(x)",
+                "spark": "DECODE(x, 'utf-8')",
             },
         )
         self.validate_all(
             "ENCODE(x, 'invalid')",
             write={
                 "presto": UnsupportedError,
+                "duckdb": UnsupportedError,
             },
         )
         self.validate_all(
             "DECODE(x, 'invalid')",
             write={
                 "presto": UnsupportedError,
+                "duckdb": UnsupportedError,
             },
         )
 
